#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 swagger2
version:              2.6
visibility:           public
id:                   swagger2-2.6-9hf8hG1jsbj6FshbNzKCyV
key:                  swagger2-2.6-9hf8hG1jsbj6FshbNzKCyV
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  184ef99b7613dbae5ec77fc8d9e99bf3
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-8.10.5/site-local/swagger2-2.6
library-dirs:         /usr/lib/ghc-8.10.5/site-local/swagger2-2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/swagger2-2.6
hs-libraries:         HSswagger2-2.6-9hf8hG1jsbj6FshbNzKCyV
depends:
    QuickCheck-2.14.2-AlBcjlnVb6HBYuJ8lOviFD
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    aeson-pretty-0.8.8-3aCNsqOVx5w7giic7jdZv7 base-4.14.2.0
    base-compat-batteries-0.11.2-Adi2U3TFDt9D7s2pHONdZC
    bytestring-0.10.12.0 containers-0.6.4.1
    cookie-0.4.5-DRjKUovO6l159RRdguKqPl
    generics-sop-0.5.1.1-JtNDPIT1a4JCUAggfmCZD9
    hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE
    http-media-0.8.0.0-BMdtrV6lKwm8BrbHWDmj81
    insert-ordered-containers-0.2.5-2SyqL4YkK326MBCs83asXO
    lens-5.0.1-9j09gzxg2dR5Wmd3U39g28 mtl-2.2.2
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M
    optics-core-0.4-ASCFnMeArQt2z7PKRP4hO3
    optics-th-0.4-1kgwoysT1ns47SviyoFJAZ
    scientific-0.3.7.0-Fi0gRGhsiJ35wgbCjOXuHX template-haskell-2.16.0.0
    text-1.2.4.1 time-1.9.3 transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    uuid-types-1.0.5-BD8YLQbwrdV1wSNOkK6P8E
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

